pub fn cleanup_task_waker(task_id: usize)Expand description
Clean up the waker for a specific task
This function should be called when a task is completely cleaned up to remove its waker from the global registry.
Arguments
task_id- The ID of the task to clean up