task_initial_kernel_entrypoint

Function task_initial_kernel_entrypoint 

pub fn task_initial_kernel_entrypoint() -> !
Internal function to perform kernel context switch between tasks This function is called when a task is first scheduled.