Struct AbiZone
Source pub struct AbiZone {
pub range: Range<usize>,
pub abi: Box<dyn AbiModule + Send + Sync>,
}
ABI Zone structure holding a memory range with an owned ABI module.
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
[From]<T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.