pub fn get_parent_waitpid_waker(parent_id: usize) -> &'static WakerExpand description
Get or create a parent waker for waitpid(-1) operations
This waker is used when a parent process calls waitpid(-1) to wait for any child to exit. It is separate from the task-specific waitpid wakers to avoid conflicts, and is used exclusively for waitpid(-1) (any child termination wait) synchronization.
Arguments
parent_id- The ID of the parent task
Returns
A reference to the parent waker