pub fn get_waitpid_waker(task_id: usize) -> &'static WakerExpand description
Get or create a waker for waitpid/wait operations for a specific task
This function returns a reference to the waker associated with the given task ID, used exclusively for waitpid/wait (child termination wait) synchronization. If no waker exists for the task, a new one is created.
Arguments
task_id- The ID of the task to get a waitpid/wait waker for
Returns
A reference to the waker for the specified task